==> treeland_0.5.20.tar.xz: BUILD/examples/test_set_treeland_wallpaper/translations/wallpaper.zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>Wallpaper</name>
    <message>
        <location filename="../Wallpaper.qml" line="48"/>
        <source>Local Picture</source>
        <translation>你的壁纸</translation>
    </message>
    <message>
        <location filename="../Wallpaper.qml" line="49"/>
        <location filename="../Wallpaper.qml" line="62"/>
        <source>Show All</source>
        <translation>全部显示</translation>
    </message>
    <message>
        <location filename="../Wallpaper.qml" line="61"/>
        <source>System Picture</source>
        <translation>系统壁纸</translation>
    </message>
    <message>
        <source>Show All </source>
        <translation type="vanished">全部显示</translation>
    </message>
</context>
<context>
    <name>WallpaperSetting</name>
    <message>
        <location filename="../WallpaperSetting.qml" line="29"/>
        <source>Wallpaper</source>
        <translation>壁纸</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="83"/>
        <source>Current Wallpaepr</source>
        <translation>当前壁纸</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="93"/>
        <source>Wallpaper Display Method</source>
        <translation>壁纸显示方式</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="100"/>
        <source>Stretch</source>
        <translation>拉伸</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="101"/>
        <source>Preserve Aspect Fit</source>
        <translation>保持外观适合</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="111"/>
        <source>Please choose a file</source>
        <translation type="unfinished">请选择文件</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="126"/>
        <source>Add Wallpaper</source>
        <translation>添加图片</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="135"/>
        <source>Add Directory</source>
        <translation type="unfinished">添加目录</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="14"/>
        <source>Wallpaper Settings</source>
        <translation>壁纸设置</translation>
    </message>
</context>
</TS>

==> treeland_0.7.3.tar.xz: BUILD/examples/test_set_treeland_wallpaper/translations/wallpaper.zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>Wallpaper</name>
    <message>
        <location filename="../Wallpaper.qml" line="48"/>
        <source>Local Picture</source>
        <translation>你的壁纸</translation>
    </message>
    <message>
        <location filename="../Wallpaper.qml" line="49"/>
        <location filename="../Wallpaper.qml" line="62"/>
        <source>Show All</source>
        <translation>全部显示</translation>
    </message>
    <message>
        <location filename="../Wallpaper.qml" line="61"/>
        <source>System Picture</source>
        <translation>系统壁纸</translation>
    </message>
</context>
<context>
    <name>WallpaperSetting</name>
    <message>
        <location filename="../WallpaperSetting.qml" line="29"/>
        <source>Wallpaper</source>
        <translation>壁纸</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="83"/>
        <source>Current Wallpaepr</source>
        <translation>当前壁纸</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="93"/>
        <source>Wallpaper Display Method</source>
        <translation>壁纸显示方式</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="100"/>
        <source>Stretch</source>
        <translation>拉伸</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="101"/>
        <source>Preserve Aspect Fit</source>
        <translation>保持外观适合</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="111"/>
        <source>Please choose a file</source>
        <translation>请选择文件</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="126"/>
        <source>Add Wallpaper</source>
        <translation>添加图片</translation>
    </message>
    <message>
        <location filename="../WallpaperSetting.qml" line="135"/>
        <source>Add Directory</source>
        <translation>添加目录</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="14"/>
        <source>Wallpaper Settings</source>
        <translation>壁纸设置</translation>
    </message>
</context>
</TS>
